function [output] = hardclip(input_gain, input,sample_rate, threshold, oversample, oversample_factor)
    %
    %   FUNCTION : hardclip takes 4 input arguments and returns the clipped signal 
    %
    %
    %   INPUTS:
    %       input_gain  - scalar multiplied to each sample of the input signal 
    %       input(double)      - time domain input signal
    %       sample_rate(double) - sample rate of the input signal 
    %       threshold(int/float)   - clipping threshold
    %       oversample(bool)       - (true) use the oversampling approach / (false) standard hard thresholding 
    %       oversample_factor - amount of oversampling 
    %
    %   OUTPUT:
    %       output - returns the clipped signal 
    %
    %   Proposed Signal Chain
    %       [input] -> [upsample] -> [hard clipping] -> [anti-alias] -> [downsample] -> [output]  
    %
    %   HINTS :
    %       (1) Recall the difference between "resample" and "upsample"
    %       functions 
    
    
    % (clipping) Limit the values in the array to the specified range
    
    % Scaled input 
    
    if (oversample)
        % Design anti-aliasing filter
        output = filter(filter_coeff,1, output);
        output = downsample(output, oversample_factor);
    end
    
end
